'use strict';

angular.module('adf.electre')
        .service('parserService',
            function () {
                /**
                 * Parser XML et JSON.
                 * @type X2JS
                 */
                var x2js = new X2JS();
                /**
                 * Parser DOM (HTML, XML, ...).
                 * @type DOMParser
                 */
                var domParser = new DOMParser();

                return {
                    /**
                     * Parse a string xml into a DOM XML using the 'domParser'.
                     * @param {String} xmlString XML specified as string
                     * @returns {Element} DOM XML
                     */
                    xmlDomFromString : function (xmlString) {
                        return domParser.parseFromString(xmlString, 'text/xml');
                    },
                    /**
                     * Parse a string html into a DOM HTML using the 'domParser'.
                     * @param {String} htmlString HTML specified as string
                     * @returns {Element} DOM HTML
                     */
                    htmlDomFromString : function (htmlString) {
                        return domParser.parseFromString(htmlString, 'text/html');
                    },
                    /**
                     * Parse a XML specified as string to a DOM Object.
                     * @param {String} xmlString XML specified as string
                     * @returns {Element} DOM XML
                     */
                    parseXmlString : function (xmlString) {
                        return x2js.parseXmlString(xmlString);
                    },
                    /**
                     * Convert a specified JSON Object to XML DOM Object.
                     * @param {Object} jsonObject
                     * @returns {Element} DOM XML
                     */
                    json2xml : function (jsonObject) {
                        return x2js.json2xml(jsonObject);
                    },
                    /**
                     * Convert a specified XML DOM Object to JSON Object.
                     * @param {Element} xmlDom
                     * @returns {Object} JSON Object
                     */
                    xml2json : function (xmlDom) {
                        return x2js.xml2json(xmlDom);
                    },
                    /**
                     * Convert a specified JSON Object to XML String.
                     * @param {Object} jsonObject
                     * @returns {String} XML String
                     */
                    json2xml_str : function (jsonObject) {
                        return x2js.json2xml_str(jsonObject);
                    },
                    /**
                     * Convert a specified XML String to JSON Object.
                     * @param {String} xmlString
                     * @returns {Object}
                     */
                    xml_str2json : function (xmlString) {
                        return x2js.xml_str2json(xmlString);
                    }
                };
            }
        );